@@ -1,49 +1,35 @@
 /*
- * Copyright 1996-2003 by Hans Reiser, licensing governed by 
+ * Copyright 1996-2004 by Hans Reiser, licensing governed by 
  * reiserfsprogs/README
  */
 
-#define _GNU_SOURCE
+#include "io.h"
 
-#include <stdio.h>
-#include <unistd.h>
 #include <string.h>
 #include <errno.h>
-#include <stdlib.h> 
 #include <asm/types.h>
 
-#include <sys/types.h>
-#include <sys/stat.h>
-
-
-#include "io.h"
-#include "misc.h"
-#include "config.h"
-
 void check_memory_msg (void) {
     fprintf(stderr, 
-	"\nThe problem has occurred looks like a hardware problem (perhaps memory).\n"
-        "Send us the bug report only if the second run dies at the same place with\n"
-        "the same block number.\n");
+	"\nThe problem has occurred looks like a hardware problem (perhaps\n"
+        "memory). Send us the bug report only if the second run dies at\n"
+	"the same place with the same block number.\n");
 }
 
 void check_hd_msg (void) {
     fprintf(stderr, 
-	"\nThe problem has occurred looks like a hardware problem.\n"
-	"If you have bad blocks, we advise you to get a new hard\n"
-	"drive, because once you get one bad block that the disk\n"
-        "drive internals cannot hide from your sight, the chances\n"
-        "of getting more are generally said to become much higher\n"
-        "(precise statistics are unknown to us), and this disk drive\n"
-        "is probably not expensive enough for you to risk your time\n"
-        "and data on it. If you don't want to follow that advice,\n"
-        "then if you have just a few bad blocks, try writing to the\n"
-        "bad blocks and see if the drive remaps the bad blocks (that\n"
-        "means it takes a block it has in reserve and allocates it\n"
-        "for use for requests of that block number).  If it cannot\n"
-        "remap the block, this could be quite bad, as it may mean\n"
-        "that so many blocks have gone bad that none remain in \n"
-	"reserve to allocate.\n");
+	"\nThe problem has occurred looks like a hardware problem. If you have\n"
+	"bad blocks, we advise you to get a new hard drive, because once you\n"
+	"get one bad block  that the disk  drive internals  cannot hide from\n"
+        "your sight,the chances of getting more are generally said to become\n"
+        "much higher  (precise statistics are unknown to us), and  this disk\n"
+        "drive is probably not expensive enough  for you to you to risk your\n"
+        "time and  data on it.  If you don't want to follow that follow that\n"
+        "advice then  if you have just a few bad blocks,  try writing to the\n"
+	"bad blocks  and see if the drive remaps  the bad blocks (that means\n"
+	"it takes a block  it has  in reserve  and allocates  it for use for\n"
+	"of that block number).  If it cannot remap the block,  use badblock\n"
+	"option (-B) with  reiserfs utils to handle this block correctly.\n");
 }
 
 static int is_bad_block (unsigned long block)
@@ -422,7 +408,8 @@ struct buffer_head * getblk (int dev, unsigned long block, int size)
 	if (buffers_memory >= buffer_soft_limit) {
 	    if (sync_buffers (&Buffer_list_head, dev, 32) == 0) {
 		grow_buffers(size);
-		buffer_soft_limit = buffers_memory + GROW_BUFFERS__NEW_BUFERS_PER_CALL * size;
+		buffer_soft_limit = buffers_memory + 
+			GROW_BUFFERS__NEW_BUFERS_PER_CALL * size;
 	    }
 	} else {
 	    if (grow_buffers(size) == 0)
@@ -432,7 +419,8 @@ struct buffer_head * getblk (int dev, unsigned long block, int size)
 	bh = get_free_buffer (&g_free_buffers, size);
 	if (bh == NULL) {
 	    show_buffers (dev, size);
-	    die ("getblk: no free buffers after grow_buffers and refill (%d)", g_nr_buffers);
+	    die ("getblk: no free buffers after grow_buffers "
+		 "and refill (%d)", g_nr_buffers);
 	}
     }
 
@@ -487,7 +475,7 @@ static int f_read(struct buffer_head * bh)
     buffer_reads++ ;
 
     offset = (unsigned long long)bh->b_size * bh->b_blocknr;
-    if (lseek64 (bh->b_dev, offset, SEEK_SET) < 0)
+    if (lseek (bh->b_dev, offset, SEEK_SET) < 0)
 	return -1;
 
     bytes = read (bh->b_dev, bh->b_data, bh->b_size);
@@ -513,19 +501,20 @@ struct buffer_head * bread (int dev, unsigned long block, size_t size)
 
     ret = f_read(bh);
     
-    if (ret > 0)
-	die ("%s: End of file, cannot read the block (%lu).\n", __FUNCTION__, bh->b_blocknr);
-    else if (ret < 0) {
+    if (ret > 0) {
+	die ("%s: End of file, cannot read the block (%lu).\n", 
+	     __FUNCTION__, block);
+    } else if (ret < 0) {
 	/* BAD BLOCK LIST SUPPORT
 	 * die ("%s: Cannot read a block # %lu. Specify list of badblocks\n",*/
 
 	if (errno == EIO) {
 	    check_hd_msg();
-	    die ("%s: Cannot read the block (%lu): (%s).\n", __FUNCTION__, 
-		bh->b_blocknr, strerror(errno));
+	    die ("%s: Cannot read the block (%lu): (%s).\n", 
+		 __FUNCTION__, block, strerror(errno));
 	} else	{
-	    fprintf (stderr, "%s: Cannot read the block (%lu): (%s).\n", __FUNCTION__, 
-		bh->b_blocknr, strerror(errno));
+	    fprintf (stderr, "%s: Cannot read the block (%lu): (%s).\n", 
+		     __FUNCTION__, block, strerror(errno));
 	    return NULL;
 	}
     }
@@ -534,26 +523,6 @@ struct buffer_head * bread (int dev, unsigned long block, size_t size)
     return bh;
 }
 
-
-int valid_offset( int fd, loff_t offset)
-{
-    char ch;
-    loff_t res;
-
-    /*res = reiserfs_llseek (fd, offset, 0);*/
-    res = lseek64 (fd, offset, SEEK_SET);
-    if (res < 0)
-	return 0;
-
-    /* if (read (fd, &ch, 1) < 0) does not wirk on files */
-    if (read (fd, &ch, 1) < 1)
-	return 0;
-
-
-    return 1;
-}
-
-
 #define ROLLBACK_FILE_START_MAGIC       "_RollBackFileForReiserfsFSCK"
 
 static struct block_handler * rollback_blocks_array;
@@ -567,12 +536,12 @@ static int rollback_blocksize;
 
 void init_rollback_file (char * rollback_file, int *blocksize, FILE * log) {
     char * string;
-    struct stat64 buf;
+    struct stat buf;
     
     if (rollback_file == NULL)
         return;
         
-    stat64(rollback_file, &buf);
+    stat(rollback_file, &buf);
     
     s_rollback_file = fopen (rollback_file, "w+");    
     if (s_rollback_file == NULL) {
@@ -611,12 +580,12 @@ static void erase_rollback_file (char * rollback_file) {
 
 int open_rollback_file (char * rollback_file, FILE * log) {
     char string [28];
-    struct stat64 buf;
+    struct stat buf;
     
     if (rollback_file == NULL)
         return -1;
     
-    if (stat64(rollback_file, &buf)) {
+    if (stat(rollback_file, &buf)) {
 	fprintf (stderr, "Cannot stat rollback file (%s)\n", rollback_file);
 	return -1;
     }
@@ -678,17 +647,17 @@ void close_rollback_file () {
 }
 
 void do_fsck_rollback (int fd_device, int fd_journal_device, FILE * progress) {
-    loff_t offset;
+    long long int offset;
     
-    struct stat64 buf;
+    struct stat buf;
     int descriptor;
     ssize_t retval;
     int count_failed = 0;
     int count_rollbacked = 0;
     
-    dev_t b_dev;
-    dev_t n_dev = 0;
-    dev_t n_journal_dev = 0;
+    int b_dev;
+    int n_dev = 0;
+    int n_journal_dev = 0;
     unsigned long total, done = 0;
 
     if (fd_device == 0) {
@@ -697,14 +666,14 @@ void do_fsck_rollback (int fd_device, int fd_journal_device, FILE * progress) {
     }
         
     if (fd_journal_device) {
-        if (!fstat64 (fd_journal_device, &buf)) {
+        if (!fstat (fd_journal_device, &buf)) {
             n_journal_dev = buf.st_rdev;
         } else {
             fprintf(stderr, "rollback: specified journal device cannot be stated\n");
         }
     }
     
-    if (!fstat64 (fd_device, &buf)) {
+    if (!fstat (fd_device, &buf)) {
         n_dev = buf.st_rdev;
     } else {
         fprintf(stderr, "rollback: specified device cannot be stated, exit\n");
@@ -753,7 +722,7 @@ void do_fsck_rollback (int fd_device, int fd_journal_device, FILE * progress) {
             continue;
         }
         
-        if (lseek64 (descriptor, offset, SEEK_SET) == (loff_t)-1) {
+        if (lseek (descriptor, offset, SEEK_SET) == (loff_t)-1) {
             fprintf(stderr, "device cannot be lseeked, skip block\n");
             count_failed ++;
             continue;
@@ -761,7 +730,7 @@ void do_fsck_rollback (int fd_device, int fd_journal_device, FILE * progress) {
         
         if (write (descriptor, rollback_data, rollback_blocksize) == -1) {
             fprintf (stderr, "rollback: write %d bytes returned error "
-		"(block=%lld, dev=%lld): %s\n", rollback_blocksize, 
+		"(block=%lld, dev=%d): %s\n", rollback_blocksize, 
 		offset/rollback_blocksize, b_dev, strerror (errno));
             count_failed ++;
         } else {
@@ -824,19 +793,19 @@ int bwrite (struct buffer_head * bh)
     size = bh->b_size;
     offset = (loff_t)size * (loff_t)bh->b_blocknr;
 
-    if (lseek64 (bh->b_dev, offset, SEEK_SET) == (loff_t)-1){
+    if (lseek (bh->b_dev, offset, SEEK_SET) == (loff_t)-1){
 	fprintf (stderr, "bwrite: lseek to position %llu (block=%lu, dev=%d): %s\n",
 	    offset, bh->b_blocknr, bh->b_dev, strerror(errno));
 	exit(8); /* File system errors left uncorrected */
     }
 
     if (s_rollback_file != NULL && bh->b_size == (unsigned long)rollback_blocksize) {
-        struct stat64 buf;
+        struct stat buf;
         __u32 position;
 	struct block_handler block_h;
         
         /*log previous content into the log*/
-        if (!fstat64 (bh->b_dev, &buf)) {
+        if (!fstat (bh->b_dev, &buf)) {
 	    block_h.blocknr = bh->b_blocknr;
 	    block_h.device = buf.st_rdev;
 	    if (reiserfs_bin_search(&block_h, rollback_blocks_array, 
@@ -866,7 +835,7 @@ int bwrite (struct buffer_head * bh)
                     exit(8);
                 }
 		
-                if (lseek64 (bh->b_dev, offset, SEEK_SET) == (loff_t)-1) {
+                if (lseek (bh->b_dev, offset, SEEK_SET) == (loff_t)-1) {
                     fprintf (stderr, "bwrite: lseek to position %llu (block=%lu, "
 			"dev=%d): %s\n", offset, bh->b_blocknr, bh->b_dev, 
 			strerror(errno));
@@ -938,11 +907,14 @@ static void check_and_free_buffer_mem (void)
     count += _check_and_free_buffer_list(g_free_buffers);
 
     if (count != g_nr_buffers)
-       die ("check_and_free_buffer_mem: found %d buffers, must be %d", count, g_nr_buffers);
+       die ("check_and_free_buffer_mem: found %d buffers, must be %d", 
+	    count, g_nr_buffers);
 
     /* free buffer heads */
     while ((next = g_buffer_heads)) {
-	g_buffer_heads = *(struct buffer_head **)(next + GROW_BUFFERS__NEW_BUFERS_PER_CALL);
+	g_buffer_heads = *(struct buffer_head **)
+		(next + GROW_BUFFERS__NEW_BUFERS_PER_CALL);
+
 	freemem (next);
     }
   
@@ -986,16 +958,3 @@ void invalidate_buffers (int dev)
     _invalidate_buffer_list(Buffer_list_head, dev) ;
     _invalidate_buffer_list(g_free_buffers, dev) ;
 }
-
-
-int user_confirmed (FILE * fp, char * q, char * yes)
-{
-    char * answer = 0;
-    size_t n = 0;
-
-    fprintf (fp, "%s", q);
-    if (getline (&answer, &n, stdin) != (ssize_t)strlen (yes) || strcmp (yes, answer))
-	return 0;
-
-    return 1;
-}
