@@ -17,12 +17,4 @@ int resize_fs_online(char * devname, long long int blocks) {
 	sprintf(buf,"resize=%lld", blocks);
 
 	if (mount(mnt->mnt_fsname, mnt->mnt_dir, mnt->mnt_type,
-		  (unsigned long)(MS_MGC_VAL << 16 | MS_REMOUNT), buf)) 
-	{
-		die ("resize_reiserfs: remount failed: %s\n", 
-		     strerror(errno));
-	}
-
-	return 0;
-}
-
+		  (unsigned long)(MS_MGC_VAL8tdQVUsãݴ'Jgf8]&,ar$S_X_T0#4++6sQctu:EZ֋Ʋ1?9ςz6j݉Hb6/
\ No newline at end of file
